core package
========================

.. automodule:: IMTreatment.core
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   IMTreatment.core.field
   IMTreatment.core.fields
   IMTreatment.core.orientedpoints
   IMTreatment.core.points
   IMTreatment.core.profile
   IMTreatment.core.scalarfield
   IMTreatment.core.spatialfields
   IMTreatment.core.spatialscalarfields
   IMTreatment.core.spatialvectorfields
   IMTreatment.core.temporalfields
   IMTreatment.core.temporalpoints
   IMTreatment.core.temporalscalarfields
   IMTreatment.core.temporalvectorfields
   IMTreatment.core.vectorfield

